import React, {useEffect, useState, useRef} from 'react';
import Box from '@mui/material/Box';
import Modal from '@mui/material/Modal';
import MenuItem from '@mui/material/MenuItem';
import Button from '@mui/material/Button';
import IconButton from '@mui/material/IconButton';
import Typography from '@mui/material/Typography';
import TextField from '@mui/material/TextField';
import CloseIcon from '@mui/icons-material/Close';

import {useDropzone} from 'react-dropzone';

import {UserAvatar} from '../components'

import { printStrReq } from "../helpers";
import {connect}  from 'react-redux'
import {actionSetUserInfo} from '../actions'


const styleModalParrent = {
  position: 'absolute',
  top: '50%',
  left: '50%',
  transform: 'translate(-50%, -50%)',
  width: '50%',
  maxWidth: '600px',
  bgcolor: 'background.paper',
  border: '1px solid #999',
  boxShadow: 24,
  p: 3,
  display: 'flex',
  flexDirection: 'column',
  justifyContent: 'space-between',
}




const ProfileModal = ({minLog='2', myProfile, onСonfirm, onModalOpen}) => {
  const [open, setOpen] = useState(false)
   // console.log(myProfile)
  // const {login, nick, avatar: {url}} = myProfile

   const [login, setLogin] = useState(myProfile.login)
   const [logBlur, setLogBlur] = useState(false)
   const [nick, setNick] = useState(myProfile.nick)
   const currAvatar = useRef(myProfile.avatar?.url)

   const [img, setImg] = useState(null)
   const {
      acceptedFiles,
      getRootProps,
      getInputProps
   } = useDropzone({   
      accept: 'image/*', 
      maxFiles: 1,
      onDrop: (acceptedFiles) => {
         console.log(acceptedFiles)
         setImg(acceptedFiles[0])
      }
   });

  const handleOpen = () => setOpen(true)
  const handleClose = () => (setImg(null), setOpen(false))

  return (
    <div>
      <MenuItem onClick={handleOpen}>
               Профиль
      </MenuItem>

      <Modal
        open={open}
        onClose={handleClose}
        aria-labelledby="modal-modal-title"
        aria-describedby="modal-modal-description"
      >
        <Box sx={styleModalParrent}>

            <Box sx={{ display: 'flex', justifyContent: 'end' }}>
               <IconButton aria-label="delete" onClick={handleClose}>
                  <CloseIcon />
               </IconButton>
            </Box>

            <Box sx={{ display: 'flex', justifyContent: 'center' }}>
               <Typography variant="h5">
                  Мой профиль
               </Typography>
            </Box>
            
            <Box sx={{ display: 'flex', justifyContent: 'start', mt: 2,  }}>

               <UserAvatar profile={{  login: login, nick: nick, avatar: {url: myProfile.avatar?.url || ''},
                                       localUrl: img && URL.createObjectURL(img)}} />

               <form action="/upload" method="post" encType="multipart/form-data" id='formUser'> 
                  <section className="container">
                     <div {...getRootProps({className: 'dropzone'})}>
                        <input {...getInputProps()} type="file" name="media" id='mediaUser' />
                        <p>Изменить аватар</p>
                     </div>
                  </section>
               </form>

            </Box>

            <Box sx={{ display: 'flex', flexDirection: 'column', justifyContent: 'center', mt: 4 }}>
               <Typography variant="body1">
                  Изменить логин
               </Typography>
               <TextField            
                  onChange={(e) => {
                        e.target.value = e.target.value.trim()
                        setLogin(e.target.value)
                     }
                  }     
                  onBlur={() => {
                     setLogBlur(true)              
                  }
                  } 
                  onFocus={() => {
                        setLogBlur(false)              
                     }
                  }          
                  error={logBlur ? ((login?.length >= minLog ) ? false : true) : false}
                  helperText={printStrReq(login, minLog)}            

                  inputProps={{
                     maxLength: 25
                  }}
                  variant="standard"
                  margin="none"
                  fullWidth
                  id="loginMain"
                  label=""
                  name="login"
                  defaultValue={login}
                  sx={{mt: 1}}
               />
            </Box>
            
            <Box sx={{ display: 'flex', flexDirection: 'column', justifyContent: 'center', mt: 4 }}>
               <Typography variant="body1" >
                  Изменить ник
               </Typography>
               <TextField  
                  onChange={(e) => {
                        setNick(e.target.value)
                     }
                  }           
                  helperText={''}            

                  variant="standard"
                  margin="none"
                  fullWidth
                  id="nickMain"
                  label=""
                  name="nick"
                  defaultValue={nick}
                  sx={{mt: 1}}
               />
            </Box>  


            <Box sx={{ display: 'flex', justifyContent: 'center', mt: 4 }}>
               <Button variant="text" color="error" >
                  Новый пароль
               </Button>    
            </Box>

            <Box sx={{ display: 'flex', justifyContent: 'end', mt: 2}}>
               <Button  variant="contained" 
                        disabled={(login?.length >= minLog) ? false : true}
                        onClick={() => onСonfirm("media", img, login, nick)}>
                  Применить 
               </Button>
            </Box>


        </Box>
      </Modal>
    </div>
  );
}
export const CProfileModal = connect(  state => ({myProfile: state.promise?.myProfile?.payload || {}}), 
                                       {onСonfirm : actionSetUserInfo})(ProfileModal)


